/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface PackerChannelConfig extends cdktf.TerraformMetaArguments {
    /**
    * The slug of the HCP Packer Registry image bucket where the channel should be created in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.61.0/docs/resources/packer_channel#bucket_name PackerChannel#bucket_name}
    */
    readonly bucketName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.61.0/docs/resources/packer_channel#id PackerChannel#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the channel being managed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.61.0/docs/resources/packer_channel#name PackerChannel#name}
    */
    readonly name: string;
    /**
    * The ID of the HCP project where this channel is located in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.61.0/docs/resources/packer_channel#project_id PackerChannel#project_id}
    */
    readonly projectId?: string;
    /**
    * iteration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.61.0/docs/resources/packer_channel#iteration PackerChannel#iteration}
    */
    readonly iteration?: PackerChannelIteration;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.61.0/docs/resources/packer_channel#timeouts PackerChannel#timeouts}
    */
    readonly timeouts?: PackerChannelTimeouts;
}
export interface PackerChannelIteration {
    /**
    * The fingerprint of the iteration assigned to the channel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.61.0/docs/resources/packer_channel#fingerprint PackerChannel#fingerprint}
    */
    readonly fingerprint?: string;
    /**
    * The ID of the iteration assigned to the channel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.61.0/docs/resources/packer_channel#id PackerChannel#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The incremental_version of the iteration assigned to the channel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.61.0/docs/resources/packer_channel#incremental_version PackerChannel#incremental_version}
    */
    readonly incrementalVersion?: number;
}
export declare function packerChannelIterationToTerraform(struct?: PackerChannelIterationOutputReference | PackerChannelIteration): any;
export declare class PackerChannelIterationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PackerChannelIteration | undefined;
    set internalValue(value: PackerChannelIteration | undefined);
    private _fingerprint?;
    get fingerprint(): string;
    set fingerprint(value: string);
    resetFingerprint(): void;
    get fingerprintInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _incrementalVersion?;
    get incrementalVersion(): number;
    set incrementalVersion(value: number);
    resetIncrementalVersion(): void;
    get incrementalVersionInput(): number | undefined;
}
export interface PackerChannelTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.61.0/docs/resources/packer_channel#create PackerChannel#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.61.0/docs/resources/packer_channel#default PackerChannel#default}
    */
    readonly default?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.61.0/docs/resources/packer_channel#delete PackerChannel#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.61.0/docs/resources/packer_channel#update PackerChannel#update}
    */
    readonly update?: string;
}
export declare function packerChannelTimeoutsToTerraform(struct?: PackerChannelTimeouts | cdktf.IResolvable): any;
export declare class PackerChannelTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PackerChannelTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: PackerChannelTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _default?;
    get default(): string;
    set default(value: string);
    resetDefault(): void;
    get defaultInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/hcp/0.61.0/docs/resources/packer_channel hcp_packer_channel}
*/
export declare class PackerChannel extends cdktf.TerraformResource {
    static readonly tfResourceType = "hcp_packer_channel";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/hcp/0.61.0/docs/resources/packer_channel hcp_packer_channel} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options PackerChannelConfig
    */
    constructor(scope: Construct, id: string, config: PackerChannelConfig);
    get authorId(): string;
    private _bucketName?;
    get bucketName(): string;
    set bucketName(value: string);
    get bucketNameInput(): string | undefined;
    get createdAt(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get organizationId(): string;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    get updatedAt(): string;
    private _iteration;
    get iteration(): PackerChannelIterationOutputReference;
    putIteration(value: PackerChannelIteration): void;
    resetIteration(): void;
    get iterationInput(): PackerChannelIteration | undefined;
    private _timeouts;
    get timeouts(): PackerChannelTimeoutsOutputReference;
    putTimeouts(value: PackerChannelTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | PackerChannelTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
